==> fontypython-0.3.0.tar.gz: fontypython-0.3.0/fontypythonmodules/dialogues.py <==
##    Fonty Python Copyright (C) 2006, 2007, 2008 Donn.C.Ingle
##    Contact: donn.ingle@gmail.com - I hope this email lasts.
##
##    This file is part of Fonty Python.
##    Fonty Python is free software: you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation, either version 3 of the License, or
##    (at your option) any later version.
##
##    Fonty Python is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with Fonty Python.  If not, see <http://www.gnu.org/licenses/>.

import fpsys
import strings
import wx
import wx.html as html

## Setup wxPython to access translations : enables the stock buttons.
langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
mylocale = wx.Locale( langid )

class DialogHelp(wx.Dialog):
    def __init__(self, *args, **kwds):
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        dbox = wx.BoxSizer(wx.VERTICAL)
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        win = TestHtmlPanel(self, size = kwds["size"]) 
        dbox.Add(win, 1, wx.EXPAND)
        dbox.Add(btn, 0, wx.EXPAND)
        self.SetSizer(dbox)
        #self.SetAutoLayout(True) #sizes it properly...
        dbox.SetSizeHints(self) #made it variable size, stops at 'size' as a min.
        #dbox.Fit(self)
        #self.Layout()
class TestHtmlPanel(wx.Panel):
    def __init__(self, parent, size):
        wx.Panel.__init__(self, parent, -1, style=wx.NO_FULL_REPAINT_ON_RESIZE)
        self.html = MyHtmlWindow(self, -1, size)
        self.box = wx.BoxSizer(wx.HORIZONTAL)
        self.box.Add(self.html, 1, wx.GROW)
        self.SetSizer(self.box)
        self.SetAutoLayout(True)
        self.html.LoadPage(fpsys.mythingsdir + "help.html")
        self.box.Fit(self)


class MyHtmlWindow(html.HtmlWindow):
    def __init__(self, parent, id, size):
        html.HtmlWindow.__init__(self, parent, id, style=wx.NO_FULL_REPAINT_ON_RESIZE, size = size)
        if "gtk2" in wx.PlatformInfo:
            self.SetStandardFonts()


class DialogAbout(wx.Dialog):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MyDialog.__init__
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        self.nb = wx.Notebook(self, -1, style=0)
        self.notebook_1_pane_2 = wx.Panel(self.nb, -1)
        self.notebook_1_pane_1 = wx.Panel(self.nb, -1)
        self.bLOGO = wx.StaticBitmap\
        (self.notebook_1_pane_1, -1, wx.Bitmap(fpsys.mythingsdir + 'aboutfplogo.png', wx.BITMAP_TYPE_ANY))
        
        self.AboutText = wx.StaticText\
        (self.notebook_1_pane_1, -1, strings.aboutText, style = wx.TE_MULTILINE)

        self.emaillink = wx.TextCtrl\
        (self.notebook_1_pane_1, -1, strings.contact, size =(200,-1 ), style = wx.TE_READONLY)        
        
        self.REPLACE_ME_WITH_A_TEXTCTRL = wx.TextCtrl\
        (self.notebook_1_pane_2, -1, strings.GPL, style=wx.TE_MULTILINE|wx.TE_READONLY)
 
        ID_ESC = 1001
        self.accel = wx.AcceleratorTable([(wx.ACCEL_NORMAL, wx.WXK_ESCAPE, ID_ESC)])
        self.SetAcceleratorTable(self.accel)
        self.Bind(wx.EVT_MENU, self.EscapeAbout, id=ID_ESC)
        
        self.__set_properties()
        self.__do_layout()
        self.notebook_1_pane_1.SetFocus() 
        # end wxGlade

    def __set_properties(self):
        self.SetTitle(_("About FontyPython"))
        _icon = wx.EmptyIcon()
        _icon.CopyFromBitmap(wx.Bitmap(fpsys.mythingsdir + 'fplogo.png', wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)

    def EscapeAbout(self, event):
        self.Close()
        
    def __do_layout(self):
        # begin wxGlade: MyDialog.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_3 = wx.BoxSizer(wx.HORIZONTAL)
        
        sizerPane1 = wx.BoxSizer(wx.HORIZONTAL)
        sizerPane1.Add(self.bLOGO, 0, 0, 0)
        
        textsizer = wx.BoxSizer(wx.VERTICAL)
        textsizer.Add(self.AboutText, 0, wx.ALIGN_LEFT | wx.ALL, border = 10)
        textsizer.Add(self.emaillink, 0, wx.ALIGN_LEFT | wx.ALL, border = 10)
        #textsizer.Add((10, 10), 0, wx.ALIGN_LEFT, 0)

        sizerPane1.Add(textsizer, 1, wx.ALIGN_BOTTOM, 0)
        
        self.notebook_1_pane_1.SetSizer(sizerPane1)
        
        sizerPane1.Fit(self.notebook_1_pane_1)
        sizerPane1.SetSizeHints(self.notebook_1_pane_1)
        
        sizer_3.Add(self.REPLACE_ME_WITH_A_TEXTCTRL,1, wx.EXPAND, 0)

        self.notebook_1_pane_2.SetSizer(sizer_3)
        sizer_3.Fit(self.notebook_1_pane_2)
        sizer_3.SetSizeHints(self.notebook_1_pane_2)
        self.nb.AddPage(self.notebook_1_pane_1, _("About"))
        self.nb.AddPage(self.notebook_1_pane_2, _("Licence"))
        sizer_1.Add(self.nb, 1, wx.EXPAND, 0)

        self.SetSizer(sizer_1)
        sizer_1.Fit(self)
        sizer_1.SetSizeHints(self)
        self.Layout()
        self.Centre()
        # end wxGlade
        

class DialogSettings(wx.Dialog):
    def __init__(self, parent):
        #-1 , "Settings", size = wx.DefaultSize, , 
        #     style = wx.DEFAULT_DIALOG_STYLE):
        wx.Dialog.__init__(self, parent, -1, _("Settings"), pos = wx.DefaultPosition, size =(450,-1))
        
        ## The layout begins:
        font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.labelHeading = wx.StaticText(self, -1, _("Settings"))
        self.labelHeading.SetFont(font)

        self.label_1 = wx.StaticText(self, -1, _("Sample text:"))
        self.inputSampleString = wx.TextCtrl(self, -1, fpsys.config.text) #, size = (200, -1)) 
        self.inputSampleString.SetFocus()
        
        self.label_2 = wx.StaticText(self, -1, _("Point size:"))
        self.inputPointSize = wx.SpinCtrl(self, -1, "")
        self.inputPointSize.SetRange(1, 500)
        self.inputPointSize.SetValue(fpsys.config.points)
        
        self.label_3 = wx.StaticText(self, -1, _("Page length:"))
        self.inputPageLen = wx.SpinCtrl(self, -1, "")
        self.inputPageLen.SetRange(1, 5000) # It's your funeral!
        self.inputPageLen.SetValue(fpsys.config.numinpage) 

        box = wx.BoxSizer(wx.HORIZONTAL)
        verticalSizer = wx.BoxSizer(wx.VERTICAL)
        box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
        gridSizer = wx.GridSizer(3, 2, 10, 10) 
        
        verticalSizer.Add(self.labelHeading, 0, 0, 0)
        
        gridSizer.Add(self.label_1, wx.ALIGN_RIGHT, 0, 0)
        gridSizer.Add(self.inputSampleString, 1, wx.EXPAND, 0)
        gridSizer.Add(self.label_2, 0, 0, 0)
        gridSizer.Add(self.inputPointSize, 0, 0, 0)
        gridSizer.Add(self.label_3, 0, 0, 0)
        gridSizer.Add(self.inputPageLen, 0, 0, 0)
        
        verticalSizer.Add(gridSizer, 1, wx.EXPAND, 0)

        btnsizer = wx.StdDialogButtonSizer()
        
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        btnsizer.AddButton(btn)

        btn = wx.Button(self, wx.ID_CANCEL)
        btnsizer.AddButton(btn)
        btnsizer.Realize()
        
        verticalSizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL| wx.ALL, border = 5)
        
        self.SetSizer(box)
        #sbox.Fit(self) #Window fits to the box.
        #box.SetSizeHints(self)
        self.Layout()


class SegfaultDialog(wx.Dialog):
    """
    Dec 2007
    Runs from the wrapper script (which runs fp) so that we
    can tell the user that there was a segfault and why.
    """
    def __init__(self, parent, culprit):
        #-1 , "Settings", size = wx.DefaultSize, , 
        #     style = wx.DEFAULT_DIALOG_STYLE):
        wx.Dialog.__init__(self, parent, -1, _("Oh boy..."), pos = wx.DefaultPosition, size =(450,-1))
        
        ## The layout begins:
        font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.labelHeading = wx.StaticText(self, -1, _("Fonty Python, um ... crashed."))
        self.labelHeading.SetFont(font)
        
        font = wx.Font(12, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.ohDear = wx.StaticText( self, -1, _("Oh dear,"))
        self.ohDear.SetFont( font )
        

        self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below.\nPlease *move* it away somewhere else, or this will keep happening. Start Fonty Python again when you are done.\n" ))

        font = wx.Font(11, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.culprit = wx.StaticText( self, -1, culprit ) 
        self.culprit.SetFont( font )
        
        box = wx.BoxSizer(wx.HORIZONTAL)
        verticalSizer = wx.BoxSizer(wx.VERTICAL)
        box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
        verticalSizer.Add(self.labelHeading, 0, 0, 0)
        verticalSizer.Add(self.ohDear, 0, 0, 0)
        verticalSizer.Add(self.sadStory, 1, wx.EXPAND, 0)
        verticalSizer.Add(self.culprit, 1, wx.EXPAND, 0)
        
        btnsizer = wx.StdDialogButtonSizer()
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        btnsizer.AddButton(btn)
        btnsizer.Realize()
                
        verticalSizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL| wx.ALL, border = 15)
        
        self.SetSizer(box)
        self.Layout()

==> fontypython-0.3.2.tar.gz: fontypython-0.3.2/fontypythonmodules/dialogues.py <==
##    Fonty Python Copyright (C) 2006, 2007, 2008 Donn.C.Ingle
##    Contact: donn.ingle@gmail.com - I hope this email lasts.
##
##    This file is part of Fonty Python.
##    Fonty Python is free software: you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation, either version 3 of the License, or
##    (at your option) any later version.
##
##    Fonty Python is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with Fonty Python.  If not, see <http://www.gnu.org/licenses/>.

import os, locale
import fpsys
import strings
import wx
import wx.html as html


## Setup wxPython to access translations : enables the stock buttons.
langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
mylocale = wx.Locale( langid )
langcode = locale.getlocale()[0][:2]

class DialogHelp(wx.Dialog):
    def __init__(self, *args, **kwds):
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        dbox = wx.BoxSizer(wx.VERTICAL)
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        win = TestHtmlPanel(self, size = kwds["size"]) 
        dbox.Add(win, 1, wx.EXPAND)
        dbox.Add(btn, 0, wx.EXPAND)
        self.SetSizer(dbox)
        #self.SetAutoLayout(True) #sizes it properly...
        dbox.SetSizeHints(self) #made it variable size, stops at 'size' as a min.
        #dbox.Fit(self)
        #self.Layout()
class TestHtmlPanel(wx.Panel):
    def __init__(self, parent, size):
        wx.Panel.__init__(self, parent, -1, style=wx.NO_FULL_REPAINT_ON_RESIZE)
        self.html = MyHtmlWindow(self, -1, size)
        self.box = wx.BoxSizer(wx.HORIZONTAL)
        self.box.Add(self.html, 1, wx.GROW)
        self.SetSizer(self.box)
        self.SetAutoLayout(True)
        
        ## Find localized help, or default to English.
        packpath = fpsys.fontyroot
        helppaf = os.path.join(packpath, "help", langcode, "help.html")
        if not os.path.exists( helppaf ):
            helppaf = os.path.join(packpath, "help", "en", "help.html")
        self.html.LoadPage( helppaf )

        self.box.Fit(self)


class MyHtmlWindow(html.HtmlWindow):
    def __init__(self, parent, id, size):
        html.HtmlWindow.__init__(self, parent, id, style=wx.NO_FULL_REPAINT_ON_RESIZE, size = size)
        if "gtk2" in wx.PlatformInfo:
            self.SetStandardFonts()


class DialogAbout(wx.Dialog):
    def __init__(self, *args, **kwds):
        # begin wxGlade: MyDialog.__init__
        kwds["style"] = wx.DEFAULT_DIALOG_STYLE
        wx.Dialog.__init__(self, *args, **kwds)
        self.nb = wx.Notebook(self, -1, style=0)
        self.notebook_1_pane_2 = wx.Panel(self.nb, -1)
        self.notebook_1_pane_1 = wx.Panel(self.nb, -1)
        self.bLOGO = wx.StaticBitmap\
        (self.notebook_1_pane_1, -1, wx.Bitmap(fpsys.mythingsdir + 'aboutfplogo.png', wx.BITMAP_TYPE_ANY))
        
        self.AboutText = wx.StaticText\
        (self.notebook_1_pane_1, -1, strings.aboutText, style = wx.TE_MULTILINE)

        self.emaillink = wx.TextCtrl\
        (self.notebook_1_pane_1, -1, strings.contact, size =(200,-1 ), style = wx.TE_READONLY)        
        
        self.REPLACE_ME_WITH_A_TEXTCTRL = wx.TextCtrl\
        (self.notebook_1_pane_2, -1, strings.GPL, style=wx.TE_MULTILINE|wx.TE_READONLY)
 
        ID_ESC = 1001
        self.accel = wx.AcceleratorTable([(wx.ACCEL_NORMAL, wx.WXK_ESCAPE, ID_ESC)])
        self.SetAcceleratorTable(self.accel)
        self.Bind(wx.EVT_MENU, self.EscapeAbout, id=ID_ESC)
        
        self.__set_properties()
        self.__do_layout()
        self.notebook_1_pane_1.SetFocus() 
        # end wxGlade

    def __set_properties(self):
        self.SetTitle(_("About FontyPython"))
        _icon = wx.EmptyIcon()
        _icon.CopyFromBitmap(wx.Bitmap(fpsys.mythingsdir + 'fplogo.png', wx.BITMAP_TYPE_ANY))
        self.SetIcon(_icon)

    def EscapeAbout(self, event):
        self.Close()
        
    def __do_layout(self):
        # begin wxGlade: MyDialog.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_3 = wx.BoxSizer(wx.HORIZONTAL)
        
        sizerPane1 = wx.BoxSizer(wx.HORIZONTAL)
        sizerPane1.Add(self.bLOGO, 0, 0, 0)
        
        textsizer = wx.BoxSizer(wx.VERTICAL)
        textsizer.Add(self.AboutText, 0, wx.ALIGN_LEFT | wx.ALL, border = 10)
        textsizer.Add(self.emaillink, 0, wx.ALIGN_LEFT | wx.ALL, border = 10)
        #textsizer.Add((10, 10), 0, wx.ALIGN_LEFT, 0)

        sizerPane1.Add(textsizer, 1, wx.ALIGN_BOTTOM, 0)
        
        self.notebook_1_pane_1.SetSizer(sizerPane1)
        
        sizerPane1.Fit(self.notebook_1_pane_1)
        sizerPane1.SetSizeHints(self.notebook_1_pane_1)
        
        sizer_3.Add(self.REPLACE_ME_WITH_A_TEXTCTRL,1, wx.EXPAND, 0)

        self.notebook_1_pane_2.SetSizer(sizer_3)
        sizer_3.Fit(self.notebook_1_pane_2)
        sizer_3.SetSizeHints(self.notebook_1_pane_2)
        self.nb.AddPage(self.notebook_1_pane_1, _("About"))
        self.nb.AddPage(self.notebook_1_pane_2, _("Licence"))
        sizer_1.Add(self.nb, 1, wx.EXPAND, 0)

        self.SetSizer(sizer_1)
        sizer_1.Fit(self)
        sizer_1.SetSizeHints(self)
        self.Layout()
        self.Centre()
        # end wxGlade
        

class DialogSettings(wx.Dialog):
    def __init__(self, parent):
        #-1 , "Settings", size = wx.DefaultSize, , 
        #     style = wx.DEFAULT_DIALOG_STYLE):
        wx.Dialog.__init__(self, parent, -1, _("Settings"), pos = wx.DefaultPosition, size =(450,-1))
        
        ## The layout begins:
        font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.labelHeading = wx.StaticText(self, -1, _("Settings"))
        self.labelHeading.SetFont(font)

        self.label_1 = wx.StaticText(self, -1, _("Sample text:"))
        self.inputSampleString = wx.TextCtrl(self, -1, fpsys.config.text) #, size = (200, -1)) 
        self.inputSampleString.SetFocus()
        
        self.label_2 = wx.StaticText(self, -1, _("Point size:"))
        self.inputPointSize = wx.SpinCtrl(self, -1, "")
        self.inputPointSize.SetRange(1, 500)
        self.inputPointSize.SetValue(fpsys.config.points)
        
        self.label_3 = wx.StaticText(self, -1, _("Page length:"))
        self.inputPageLen = wx.SpinCtrl(self, -1, "")
        self.inputPageLen.SetRange(1, 5000) # It's your funeral!
        self.inputPageLen.SetValue(fpsys.config.numinpage) 

        box = wx.BoxSizer(wx.HORIZONTAL)
        verticalSizer = wx.BoxSizer(wx.VERTICAL)
        box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
        gridSizer = wx.GridSizer(3, 2, 10, 10) 
        
        verticalSizer.Add(self.labelHeading, 0, 0, 0)
        
        gridSizer.Add(self.label_1, wx.ALIGN_RIGHT, 0, 0)
        gridSizer.Add(self.inputSampleString, 1, wx.EXPAND, 0)
        gridSizer.Add(self.label_2, 0, 0, 0)
        gridSizer.Add(self.inputPointSize, 0, 0, 0)
        gridSizer.Add(self.label_3, 0, 0, 0)
        gridSizer.Add(self.inputPageLen, 0, 0, 0)
        
        verticalSizer.Add(gridSizer, 1, wx.EXPAND, 0)

        btnsizer = wx.StdDialogButtonSizer()
        
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        btnsizer.AddButton(btn)

        btn = wx.Button(self, wx.ID_CANCEL)
        btnsizer.AddButton(btn)
        btnsizer.Realize()
        
        verticalSizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL| wx.ALL, border = 5)
        
        self.SetSizer(box)
        #sbox.Fit(self) #Window fits to the box.
        #box.SetSizeHints(self)
        self.Layout()


class SegfaultDialog(wx.Dialog):
    """
    Dec 2007
    Runs from the wrapper script (which runs fp) so that we
    can tell the user that there was a segfault and why.
    """
    def __init__(self, parent, culprit):
        #-1 , "Settings", size = wx.DefaultSize, , 
        #     style = wx.DEFAULT_DIALOG_STYLE):
        wx.Dialog.__init__(self, parent, -1, _("Oh boy..."), pos = wx.DefaultPosition, size =(450,-1))
        
        ## The layout begins:
        font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.labelHeading = wx.StaticText(self, -1, _("Fonty Python, um ... crashed."))
        self.labelHeading.SetFont(font)
        
        font = wx.Font(12, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.ohDear = wx.StaticText( self, -1, _("Oh dear,"))
        self.ohDear.SetFont( font )
        

        self.sadStory = wx.StaticText( self, -1, _("There's some problem with the font named below.\nPlease *move* it away somewhere else, or this will keep happening. Start Fonty Python again when you are done.\n" ))

        font = wx.Font(11, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        self.culprit = wx.StaticText( self, -1, culprit ) 
        self.culprit.SetFont( font )
        
        box = wx.BoxSizer(wx.HORIZONTAL)
        verticalSizer = wx.BoxSizer(wx.VERTICAL)
        box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
        verticalSizer.Add(self.labelHeading, 0, 0, 0)
        verticalSizer.Add(self.ohDear, 0, 0, 0)
        verticalSizer.Add(self.sadStory, 1, wx.EXPAND, 0)
        verticalSizer.Add(self.culprit, 1, wx.EXPAND, 0)
        
        btnsizer = wx.StdDialogButtonSizer()
        btn = wx.Button(self, wx.ID_OK)
        btn.SetDefault()
        btnsizer.AddButton(btn)
        btnsizer.Realize()
                
        verticalSizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL| wx.ALL, border = 15)
        
        self.SetSizer(box)
        self.Layout()
